# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('lti_provider', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lticoursecontext',
            name='lms_context_id',
        ),
        migrations.AddField(
            model_name='lticoursecontext',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-10-09 12:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lti_provider', '0004_lticoursecontext_enable'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lticoursecontext',
            name='enable',
        ),
        migrations.RemoveField(
            model_name='lticoursecontext',
            name='uuid',
        ),
        migrations.AddField(
            model_name='lticoursecontext',
            name='lms_course_context',
            field=models.TextField(null=True, unique=True),
        ),
    ]
